'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def add_tags_to_stream(StreamName=None, Tags=None):
    """
    Adds or updates tags for the specified Amazon Kinesis stream. Each stream can have up to 10 tags.
    If tags have already been assigned to the stream, AddTagsToStream overwrites any existing tags that correspond to the specified tag keys.
    See also: AWS API Documentation
    
    
    :example: response = client.add_tags_to_stream(
        StreamName='string',
        Tags={
            'string': 'string'
        }
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream.
            

    :type Tags: dict
    :param Tags: [REQUIRED]
            The set of key-value pairs to use to create the tags.
            (string) --
            (string) --
            

    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def create_stream(StreamName=None, ShardCount=None):
    """
    Creates an Amazon Kinesis stream. A stream captures and transports data records that are continuously emitted from different data sources or producers . Scale-out within a stream is explicitly supported by means of shards, which are uniquely identified groups of data records in a stream.
    You specify and control the number of shards that a stream is composed of. Each shard can support reads up to 5 transactions per second, up to a maximum data read total of 2 MB per second. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MB per second. You can add shards to a stream if the amount of data input increases and you can remove shards if the amount of data input decreases.
    The stream name identifies the stream. The name is scoped to the AWS account used by the application. It is also scoped by region. That is, two streams in two different accounts can have the same name, and two streams in the same account, but in two different regions, can have the same name.
    You receive a LimitExceededException when making a CreateStream request if you try to do one of the following:
    For the default shard limit for an AWS account, see Streams Limits in the Amazon Kinesis Streams Developer Guide . If you need to increase this limit, contact AWS Support .
    You can use DescribeStream to check the stream status, which is returned in StreamStatus .
    See also: AWS API Documentation
    
    
    :example: response = client.create_stream(
        StreamName='string',
        ShardCount=123
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            A name to identify the stream. The stream name is scoped to the AWS account used by the application that creates the stream. It is also scoped by region. That is, two streams in two different AWS accounts can have the same name, and two streams in the same AWS account but in two different regions can have the same name.
            

    :type ShardCount: integer
    :param ShardCount: [REQUIRED]
            The number of shards that the stream will use. The throughput of the stream is a function of the number of shards; more shards are required for greater provisioned throughput.
            DefaultShardLimit;
            

    :returns: 
    StreamName (string) -- [REQUIRED]
    A name to identify the stream. The stream name is scoped to the AWS account used by the application that creates the stream. It is also scoped by region. That is, two streams in two different AWS accounts can have the same name, and two streams in the same AWS account but in two different regions can have the same name.
    
    ShardCount (integer) -- [REQUIRED]
    The number of shards that the stream will use. The throughput of the stream is a function of the number of shards; more shards are required for greater provisioned throughput.
    DefaultShardLimit;
    
    
    """
    pass

def decrease_stream_retention_period(StreamName=None, RetentionPeriodHours=None):
    """
    Decreases the Amazon Kinesis stream's retention period, which is the length of time data records are accessible after they are added to the stream. The minimum value of a stream's retention period is 24 hours.
    This operation may result in lost data. For example, if the stream's retention period is 48 hours and is decreased to 24 hours, any data already in the stream that is older than 24 hours is inaccessible.
    See also: AWS API Documentation
    
    
    :example: response = client.decrease_stream_retention_period(
        StreamName='string',
        RetentionPeriodHours=123
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream to modify.
            

    :type RetentionPeriodHours: integer
    :param RetentionPeriodHours: [REQUIRED]
            The new retention period of the stream, in hours. Must be less than the current retention period.
            

    """
    pass

def delete_stream(StreamName=None):
    """
    Deletes an Amazon Kinesis stream and all its shards and data. You must shut down any applications that are operating on the stream before you delete the stream. If an application attempts to operate on a deleted stream, it will receive the exception ResourceNotFoundException .
    If the stream is in the ACTIVE state, you can delete it. After a DeleteStream request, the specified stream is in the DELETING state until Amazon Kinesis completes the deletion.
    When you delete a stream, any shards in that stream are also deleted, and any tags are dissociated from the stream.
    You can use the  DescribeStream operation to check the state of the stream, which is returned in StreamStatus .
    See also: AWS API Documentation
    
    
    :example: response = client.delete_stream(
        StreamName='string'
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream to delete.
            

    """
    pass

def describe_limits():
    """
    Describes the shard limits and usage for the account.
    If you update your account limits, the old limits might be returned for a few minutes.
    This operation has a limit of 1 transaction per second per account.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_limits()
    
    
    :rtype: dict
    :return: {
        'ShardLimit': 123,
        'OpenShardCount': 123
    }
    
    
    """
    pass

def describe_stream(StreamName=None, Limit=None, ExclusiveStartShardId=None):
    """
    Describes the specified Amazon Kinesis stream.
    The information returned includes the stream name, Amazon Resource Name (ARN), creation time, enhanced metric configuration, and shard map. The shard map is an array of shard objects. For each shard object, there is the hash key and sequence number ranges that the shard spans, and the IDs of any earlier shards that played in a role in creating the shard. Every record ingested in the stream is identified by a sequence number, which is assigned when the record is put into the stream.
    You can limit the number of shards returned by each call. For more information, see Retrieving Shards from a Stream in the Amazon Kinesis Streams Developer Guide .
    There are no guarantees about the chronological order shards returned. To process shards in chronological order, use the ID of the parent shard to track the lineage to the oldest shard.
    This operation has a limit of 10 transactions per second per account.
    See also: AWS API Documentation
    
    
    :example: response = client.describe_stream(
        StreamName='string',
        Limit=123,
        ExclusiveStartShardId='string'
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream to describe.
            

    :type Limit: integer
    :param Limit: The maximum number of shards to return in a single call. The default value is 100. If you specify a value greater than 100, at most 100 shards are returned.

    :type ExclusiveStartShardId: string
    :param ExclusiveStartShardId: The shard ID of the shard to start with.

    :rtype: dict
    :return: {
        'StreamDescription': {
            'StreamName': 'string',
            'StreamARN': 'string',
            'StreamStatus': 'CREATING'|'DELETING'|'ACTIVE'|'UPDATING',
            'Shards': [
                {
                    'ShardId': 'string',
                    'ParentShardId': 'string',
                    'AdjacentParentShardId': 'string',
                    'HashKeyRange': {
                        'StartingHashKey': 'string',
                        'EndingHashKey': 'string'
                    },
                    'SequenceNumberRange': {
                        'StartingSequenceNumber': 'string',
                        'EndingSequenceNumber': 'string'
                    }
                },
            ],
            'HasMoreShards': True|False,
            'RetentionPeriodHours': 123,
            'StreamCreationTimestamp': datetime(2015, 1, 1),
            'EnhancedMonitoring': [
                {
                    'ShardLevelMetrics': [
                        'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
                    ]
                },
            ]
        }
    }
    
    
    :returns: 
    CREATING - The stream is being created. Amazon Kinesis immediately returns and sets StreamStatus to CREATING .
    DELETING - The stream is being deleted. The specified stream is in the DELETING state until Amazon Kinesis completes the deletion.
    ACTIVE - The stream exists and is ready for read and write operations or deletion. You should perform read and write operations only on an ACTIVE stream.
    UPDATING - Shards in the stream are being merged or split. Read and write operations continue to work while the stream is in the UPDATING state.
    
    """
    pass

def disable_enhanced_monitoring(StreamName=None, ShardLevelMetrics=None):
    """
    Disables enhanced monitoring.
    See also: AWS API Documentation
    
    
    :example: response = client.disable_enhanced_monitoring(
        StreamName='string',
        ShardLevelMetrics=[
            'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
        ]
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the Amazon Kinesis stream for which to disable enhanced monitoring.
            

    :type ShardLevelMetrics: list
    :param ShardLevelMetrics: [REQUIRED]
            List of shard-level metrics to disable.
            The following are the valid shard-level metrics. The value 'ALL ' disables every metric.
            IncomingBytes
            IncomingRecords
            OutgoingBytes
            OutgoingRecords
            WriteProvisionedThroughputExceeded
            ReadProvisionedThroughputExceeded
            IteratorAgeMilliseconds
            ALL
            For more information, see Monitoring the Amazon Kinesis Streams Service with Amazon CloudWatch in the Amazon Kinesis Streams Developer Guide .
            (string) --
            

    :rtype: dict
    :return: {
        'StreamName': 'string',
        'CurrentShardLevelMetrics': [
            'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
        ],
        'DesiredShardLevelMetrics': [
            'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def enable_enhanced_monitoring(StreamName=None, ShardLevelMetrics=None):
    """
    Enables enhanced Amazon Kinesis stream monitoring for shard-level metrics.
    See also: AWS API Documentation
    
    
    :example: response = client.enable_enhanced_monitoring(
        StreamName='string',
        ShardLevelMetrics=[
            'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
        ]
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream for which to enable enhanced monitoring.
            

    :type ShardLevelMetrics: list
    :param ShardLevelMetrics: [REQUIRED]
            List of shard-level metrics to enable.
            The following are the valid shard-level metrics. The value 'ALL ' enables every metric.
            IncomingBytes
            IncomingRecords
            OutgoingBytes
            OutgoingRecords
            WriteProvisionedThroughputExceeded
            ReadProvisionedThroughputExceeded
            IteratorAgeMilliseconds
            ALL
            For more information, see Monitoring the Amazon Kinesis Streams Service with Amazon CloudWatch in the Amazon Kinesis Streams Developer Guide .
            (string) --
            

    :rtype: dict
    :return: {
        'StreamName': 'string',
        'CurrentShardLevelMetrics': [
            'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
        ],
        'DesiredShardLevelMetrics': [
            'IncomingBytes'|'IncomingRecords'|'OutgoingBytes'|'OutgoingRecords'|'WriteProvisionedThroughputExceeded'|'ReadProvisionedThroughputExceeded'|'IteratorAgeMilliseconds'|'ALL',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_records(ShardIterator=None, Limit=None):
    """
    Gets data records from an Amazon Kinesis stream's shard.
    Specify a shard iterator using the ShardIterator parameter. The shard iterator specifies the position in the shard from which you want to start reading data records sequentially. If there are no records available in the portion of the shard that the iterator points to,  GetRecords returns an empty list. Note that it might take multiple calls to get to a portion of the shard that contains records.
    You can scale by provisioning multiple shards per stream while considering service limits (for more information, see Streams Limits in the Amazon Kinesis Streams Developer Guide ). Your application should have one thread per shard, each reading continuously from its stream. To read from a stream continually, call  GetRecords in a loop. Use  GetShardIterator to get the shard iterator to specify in the first  GetRecords call.  GetRecords returns a new shard iterator in NextShardIterator . Specify the shard iterator returned in NextShardIterator in subsequent calls to  GetRecords . Note that if the shard has been closed, the shard iterator can't return more data and  GetRecords returns null in NextShardIterator . You can terminate the loop when the shard is closed, or when the shard iterator reaches the record with the sequence number or other attribute that marks it as the last record to process.
    Each data record can be up to 1 MB in size, and each shard can read up to 2 MB per second. You can ensure that your calls don't exceed the maximum supported size or throughput by using the Limit parameter to specify the maximum number of records that  GetRecords can return. Consider your average record size when determining this limit.
    The size of the data returned by  GetRecords varies depending on the utilization of the shard. The maximum size of data that  GetRecords can return is 10 MB. If a call returns this amount of data, subsequent calls made within the next 5 seconds throw ProvisionedThroughputExceededException . If there is insufficient provisioned throughput on the shard, subsequent calls made within the next 1 second throw ProvisionedThroughputExceededException . Note that  GetRecords won't return any data when it throws an exception. For this reason, we recommend that you wait one second between calls to  GetRecords ; however, it's possible that the application will get exceptions for longer than 1 second.
    To detect whether the application is falling behind in processing, you can use the MillisBehindLatest response attribute. You can also monitor the stream using CloudWatch metrics and other mechanisms (see Monitoring in the Amazon Kinesis Streams Developer Guide ).
    Each Amazon Kinesis record includes a value, ApproximateArrivalTimestamp , that is set when a stream successfully receives and stores a record. This is commonly referred to as a server-side timestamp, whereas a client-side timestamp is set when a data producer creates or sends the record to a stream (a data producer is any data source putting data records into a stream, for example with  PutRecords ). The timestamp has millisecond precision. There are no guarantees about the timestamp accuracy, or that the timestamp is always increasing. For example, records in a shard or across a stream might have timestamps that are out of order.
    See also: AWS API Documentation
    
    
    :example: response = client.get_records(
        ShardIterator='string',
        Limit=123
    )
    
    
    :type ShardIterator: string
    :param ShardIterator: [REQUIRED]
            The position in the shard from which you want to start sequentially reading data records. A shard iterator specifies this position using the sequence number of a data record in the shard.
            

    :type Limit: integer
    :param Limit: The maximum number of records to return. Specify a value of up to 10,000. If you specify a value that is greater than 10,000, GetRecords throws InvalidArgumentException .

    :rtype: dict
    :return: {
        'Records': [
            {
                'SequenceNumber': 'string',
                'ApproximateArrivalTimestamp': datetime(2015, 1, 1),
                'Data': b'bytes',
                'PartitionKey': 'string'
            },
        ],
        'NextShardIterator': 'string',
        'MillisBehindLatest': 123
    }
    
    
    """
    pass

def get_shard_iterator(StreamName=None, ShardId=None, ShardIteratorType=None, StartingSequenceNumber=None, Timestamp=None):
    """
    Gets an Amazon Kinesis shard iterator. A shard iterator expires five minutes after it is returned to the requester.
    A shard iterator specifies the shard position from which to start reading data records sequentially. The position is specified using the sequence number of a data record in a shard. A sequence number is the identifier associated with every record ingested in the stream, and is assigned when a record is put into the stream. Each stream has one or more shards.
    You must specify the shard iterator type. For example, you can set the ShardIteratorType parameter to read exactly from the position denoted by a specific sequence number by using the AT_SEQUENCE_NUMBER shard iterator type, or right after the sequence number by using the AFTER_SEQUENCE_NUMBER shard iterator type, using sequence numbers returned by earlier calls to  PutRecord ,  PutRecords ,  GetRecords , or  DescribeStream . In the request, you can specify the shard iterator type AT_TIMESTAMP to read records from an arbitrary point in time, TRIM_HORIZON to cause ShardIterator to point to the last untrimmed record in the shard in the system (the oldest data record in the shard), or LATEST so that you always read the most recent data in the shard.
    When you read repeatedly from a stream, use a  GetShardIterator request to get the first shard iterator for use in your first  GetRecords request and for subsequent reads use the shard iterator returned by the  GetRecords request in NextShardIterator . A new shard iterator is returned by every  GetRecords request in NextShardIterator , which you use in the ShardIterator parameter of the next  GetRecords request.
    If a  GetShardIterator request is made too often, you receive a ProvisionedThroughputExceededException . For more information about throughput limits, see  GetRecords , and Streams Limits in the Amazon Kinesis Streams Developer Guide .
    If the shard is closed,  GetShardIterator returns a valid iterator for the last sequence number of the shard. Note that a shard can be closed as a result of using  SplitShard or  MergeShards .
    See also: AWS API Documentation
    
    
    :example: response = client.get_shard_iterator(
        StreamName='string',
        ShardId='string',
        ShardIteratorType='AT_SEQUENCE_NUMBER'|'AFTER_SEQUENCE_NUMBER'|'TRIM_HORIZON'|'LATEST'|'AT_TIMESTAMP',
        StartingSequenceNumber='string',
        Timestamp=datetime(2015, 1, 1)
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the Amazon Kinesis stream.
            

    :type ShardId: string
    :param ShardId: [REQUIRED]
            The shard ID of the Amazon Kinesis shard to get the iterator for.
            

    :type ShardIteratorType: string
    :param ShardIteratorType: [REQUIRED]
            Determines how the shard iterator is used to start reading data records from the shard.
            The following are the valid Amazon Kinesis shard iterator types:
            AT_SEQUENCE_NUMBER - Start reading from the position denoted by a specific sequence number, provided in the value StartingSequenceNumber .
            AFTER_SEQUENCE_NUMBER - Start reading right after the position denoted by a specific sequence number, provided in the value StartingSequenceNumber .
            AT_TIMESTAMP - Start reading from the position denoted by a specific timestamp, provided in the value Timestamp .
            TRIM_HORIZON - Start reading at the last untrimmed record in the shard in the system, which is the oldest data record in the shard.
            LATEST - Start reading just after the most recent record in the shard, so that you always read the most recent data in the shard.
            

    :type StartingSequenceNumber: string
    :param StartingSequenceNumber: The sequence number of the data record in the shard from which to start reading. Used with shard iterator type AT_SEQUENCE_NUMBER and AFTER_SEQUENCE_NUMBER.

    :type Timestamp: datetime
    :param Timestamp: The timestamp of the data record from which to start reading. Used with shard iterator type AT_TIMESTAMP. A timestamp is the Unix epoch date with precision in milliseconds. For example, 2016-04-04T19:58:46.480-00:00 or 1459799926.480 . If a record with this exact timestamp does not exist, the iterator returned is for the next (later) record. If the timestamp is older than the current trim horizon, the iterator returned is for the oldest untrimmed data record (TRIM_HORIZON).

    :rtype: dict
    :return: {
        'ShardIterator': 'string'
    }
    
    
    """
    pass

def get_waiter():
    """
    
    """
    pass

def increase_stream_retention_period(StreamName=None, RetentionPeriodHours=None):
    """
    Increases the Amazon Kinesis stream's retention period, which is the length of time data records are accessible after they are added to the stream. The maximum value of a stream's retention period is 168 hours (7 days).
    Upon choosing a longer stream retention period, this operation will increase the time period records are accessible that have not yet expired. However, it will not make previous data that has expired (older than the stream's previous retention period) accessible after the operation has been called. For example, if a stream's retention period is set to 24 hours and is increased to 168 hours, any data that is older than 24 hours will remain inaccessible to consumer applications.
    See also: AWS API Documentation
    
    
    :example: response = client.increase_stream_retention_period(
        StreamName='string',
        RetentionPeriodHours=123
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream to modify.
            

    :type RetentionPeriodHours: integer
    :param RetentionPeriodHours: [REQUIRED]
            The new retention period of the stream, in hours. Must be more than the current retention period.
            

    """
    pass

def list_streams(Limit=None, ExclusiveStartStreamName=None):
    """
    Lists your Amazon Kinesis streams.
    The number of streams may be too large to return from a single call to ListStreams . You can limit the number of returned streams using the Limit parameter. If you do not specify a value for the Limit parameter, Amazon Kinesis uses the default limit, which is currently 10.
    You can detect if there are more streams available to list by using the HasMoreStreams flag from the returned output. If there are more streams available, you can request more streams by using the name of the last stream returned by the ListStreams request in the ExclusiveStartStreamName parameter in a subsequent request to ListStreams . The group of stream names returned by the subsequent request is then added to the list. You can continue this process until all the stream names have been collected in the list.
    See also: AWS API Documentation
    
    
    :example: response = client.list_streams(
        Limit=123,
        ExclusiveStartStreamName='string'
    )
    
    
    :type Limit: integer
    :param Limit: The maximum number of streams to list.

    :type ExclusiveStartStreamName: string
    :param ExclusiveStartStreamName: The name of the stream to start the list with.

    :rtype: dict
    :return: {
        'StreamNames': [
            'string',
        ],
        'HasMoreStreams': True|False
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def list_tags_for_stream(StreamName=None, ExclusiveStartTagKey=None, Limit=None):
    """
    Lists the tags for the specified Amazon Kinesis stream.
    See also: AWS API Documentation
    
    
    :example: response = client.list_tags_for_stream(
        StreamName='string',
        ExclusiveStartTagKey='string',
        Limit=123
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream.
            

    :type ExclusiveStartTagKey: string
    :param ExclusiveStartTagKey: The key to use as the starting point for the list of tags. If this parameter is set, ListTagsForStream gets all tags that occur after ExclusiveStartTagKey .

    :type Limit: integer
    :param Limit: The number of tags to return. If this number is less than the total number of tags associated with the stream, HasMoreTags is set to true . To list additional tags, set ExclusiveStartTagKey to the last key in the response.

    :rtype: dict
    :return: {
        'Tags': [
            {
                'Key': 'string',
                'Value': 'string'
            },
        ],
        'HasMoreTags': True|False
    }
    
    
    """
    pass

def merge_shards(StreamName=None, ShardToMerge=None, AdjacentShardToMerge=None):
    """
    Merges two adjacent shards in an Amazon Kinesis stream and combines them into a single shard to reduce the stream's capacity to ingest and transport data. Two shards are considered adjacent if the union of the hash key ranges for the two shards form a contiguous set with no gaps. For example, if you have two shards, one with a hash key range of 276...381 and the other with a hash key range of 382...454, then you could merge these two shards into a single shard that would have a hash key range of 276...454. After the merge, the single child shard receives data for all hash key values covered by the two parent shards.
    If the stream is in the ACTIVE state, you can call MergeShards . If a stream is in the CREATING , UPDATING , or DELETING state, MergeShards returns a ResourceInUseException . If the specified stream does not exist, MergeShards returns a ResourceNotFoundException .
    You can use  DescribeStream to check the state of the stream, which is returned in StreamStatus .
    You use  DescribeStream to determine the shard IDs that are specified in the MergeShards request.
    If you try to operate on too many streams in parallel using  CreateStream ,  DeleteStream , MergeShards or  SplitShard , you will receive a LimitExceededException .
    See also: AWS API Documentation
    
    
    :example: response = client.merge_shards(
        StreamName='string',
        ShardToMerge='string',
        AdjacentShardToMerge='string'
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream for the merge.
            

    :type ShardToMerge: string
    :param ShardToMerge: [REQUIRED]
            The shard ID of the shard to combine with the adjacent shard for the merge.
            

    :type AdjacentShardToMerge: string
    :param AdjacentShardToMerge: [REQUIRED]
            The shard ID of the adjacent shard for the merge.
            

    """
    pass

def put_record(StreamName=None, Data=None, PartitionKey=None, ExplicitHashKey=None, SequenceNumberForOrdering=None):
    """
    Writes a single data record into an Amazon Kinesis stream. Call PutRecord to send data into the stream for real-time ingestion and subsequent processing, one record at a time. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MB per second.
    You must specify the name of the stream that captures, stores, and transports the data; a partition key; and the data blob itself.
    The data blob can be any type of data; for example, a segment from a log file, geographic/location data, website clickstream data, and so on.
    The partition key is used by Amazon Kinesis to distribute data across shards. Amazon Kinesis segregates the data records that belong to a stream into multiple shards, using the partition key associated with each data record to determine which shard a given data record belongs to.
    Partition keys are Unicode strings, with a maximum length limit of 256 characters for each key. An MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards using the hash key ranges of the shards. You can override hashing the partition key to determine the shard by explicitly specifying a hash value using the ExplicitHashKey parameter. For more information, see Adding Data to a Stream in the Amazon Kinesis Streams Developer Guide .
    Sequence numbers increase over time and are specific to a shard within a stream, not across all shards within a stream. To guarantee strictly increasing ordering, write serially to a shard and use the SequenceNumberForOrdering parameter. For more information, see Adding Data to a Stream in the Amazon Kinesis Streams Developer Guide .
    If a PutRecord request cannot be processed because of insufficient provisioned throughput on the shard involved in the request, PutRecord throws ProvisionedThroughputExceededException .
    Data records are accessible for only 24 hours from the time that they are added to a stream.
    See also: AWS API Documentation
    
    
    :example: response = client.put_record(
        StreamName='string',
        Data=b'bytes',
        PartitionKey='string',
        ExplicitHashKey='string',
        SequenceNumberForOrdering='string'
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream to put the data record into.
            

    :type Data: bytes
    :param Data: [REQUIRED]
            The data blob to put into the record, which is base64-encoded when the blob is serialized. When the data blob (the payload before base64-encoding) is added to the partition key size, the total size must not exceed the maximum record size (1 MB).
            

    :type PartitionKey: string
    :param PartitionKey: [REQUIRED]
            Determines which shard in the stream the data record is assigned to. Partition keys are Unicode strings with a maximum length limit of 256 characters for each key. Amazon Kinesis uses the partition key as input to a hash function that maps the partition key and associated data to a specific shard. Specifically, an MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards. As a result of this hashing mechanism, all data records with the same partition key map to the same shard within the stream.
            

    :type ExplicitHashKey: string
    :param ExplicitHashKey: The hash value used to explicitly determine the shard the data record is assigned to by overriding the partition key hash.

    :type SequenceNumberForOrdering: string
    :param SequenceNumberForOrdering: Guarantees strictly increasing sequence numbers, for puts from the same client and to the same partition key. Usage: set the SequenceNumberForOrdering of record n to the sequence number of record n-1 (as returned in the result when putting record n-1 ). If this parameter is not set, records will be coarsely ordered based on arrival time.

    :rtype: dict
    :return: {
        'ShardId': 'string',
        'SequenceNumber': 'string'
    }
    
    
    """
    pass

def put_records(Records=None, StreamName=None):
    """
    Writes multiple data records into an Amazon Kinesis stream in a single call (also referred to as a PutRecords request). Use this operation to send data into the stream for data ingestion and processing.
    Each PutRecords request can support up to 500 records. Each record in the request can be as large as 1 MB, up to a limit of 5 MB for the entire request, including partition keys. Each shard can support writes up to 1,000 records per second, up to a maximum data write total of 1 MB per second.
    You must specify the name of the stream that captures, stores, and transports the data; and an array of request Records , with each record in the array requiring a partition key and data blob. The record size limit applies to the total size of the partition key and data blob.
    The data blob can be any type of data; for example, a segment from a log file, geographic/location data, website clickstream data, and so on.
    The partition key is used by Amazon Kinesis as input to a hash function that maps the partition key and associated data to a specific shard. An MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards. As a result of this hashing mechanism, all data records with the same partition key map to the same shard within the stream. For more information, see Adding Data to a Stream in the Amazon Kinesis Streams Developer Guide .
    Each record in the Records array may include an optional parameter, ExplicitHashKey , which overrides the partition key to shard mapping. This parameter allows a data producer to determine explicitly the shard where the record is stored. For more information, see Adding Multiple Records with PutRecords in the Amazon Kinesis Streams Developer Guide .
    The PutRecords response includes an array of response Records . Each record in the response array directly correlates with a record in the request array using natural ordering, from the top to the bottom of the request and response. The response Records array always includes the same number of records as the request array.
    The response Records array includes both successfully and unsuccessfully processed records. Amazon Kinesis attempts to process all records in each PutRecords request. A single record failure does not stop the processing of subsequent records.
    A successfully-processed record includes ShardId and SequenceNumber values. The ShardId parameter identifies the shard in the stream where the record is stored. The SequenceNumber parameter is an identifier assigned to the put record, unique to all records in the stream.
    An unsuccessfully-processed record includes ErrorCode and ErrorMessage values. ErrorCode reflects the type of error and can be one of the following values: ProvisionedThroughputExceededException or InternalFailure . ErrorMessage provides more detailed information about the ProvisionedThroughputExceededException exception including the account ID, stream name, and shard ID of the record that was throttled. For more information about partially successful responses, see Adding Multiple Records with PutRecords in the Amazon Kinesis Streams Developer Guide .
    By default, data records are accessible for only 24 hours from the time that they are added to an Amazon Kinesis stream. This retention period can be modified using the  DecreaseStreamRetentionPeriod and  IncreaseStreamRetentionPeriod operations.
    See also: AWS API Documentation
    
    
    :example: response = client.put_records(
        Records=[
            {
                'Data': b'bytes',
                'ExplicitHashKey': 'string',
                'PartitionKey': 'string'
            },
        ],
        StreamName='string'
    )
    
    
    :type Records: list
    :param Records: [REQUIRED]
            The records associated with the request.
            (dict) --Represents the output for PutRecords .
            Data (bytes) -- [REQUIRED]The data blob to put into the record, which is base64-encoded when the blob is serialized. When the data blob (the payload before base64-encoding) is added to the partition key size, the total size must not exceed the maximum record size (1 MB).
            ExplicitHashKey (string) --The hash value used to determine explicitly the shard that the data record is assigned to by overriding the partition key hash.
            PartitionKey (string) -- [REQUIRED]Determines which shard in the stream the data record is assigned to. Partition keys are Unicode strings with a maximum length limit of 256 characters for each key. Amazon Kinesis uses the partition key as input to a hash function that maps the partition key and associated data to a specific shard. Specifically, an MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards. As a result of this hashing mechanism, all data records with the same partition key map to the same shard within the stream.
            
            

    :type StreamName: string
    :param StreamName: [REQUIRED]
            The stream name associated with the request.
            

    :rtype: dict
    :return: {
        'FailedRecordCount': 123,
        'Records': [
            {
                'SequenceNumber': 'string',
                'ShardId': 'string',
                'ErrorCode': 'string',
                'ErrorMessage': 'string'
            },
        ]
    }
    
    
    """
    pass

def remove_tags_from_stream(StreamName=None, TagKeys=None):
    """
    Removes tags from the specified Amazon Kinesis stream. Removed tags are deleted and cannot be recovered after this operation successfully completes.
    If you specify a tag that does not exist, it is ignored.
    See also: AWS API Documentation
    
    
    :example: response = client.remove_tags_from_stream(
        StreamName='string',
        TagKeys=[
            'string',
        ]
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream.
            

    :type TagKeys: list
    :param TagKeys: [REQUIRED]
            A list of tag keys. Each corresponding tag is removed from the stream.
            (string) --
            

    """
    pass

def split_shard(StreamName=None, ShardToSplit=None, NewStartingHashKey=None):
    """
    Splits a shard into two new shards in the Amazon Kinesis stream to increase the stream's capacity to ingest and transport data. SplitShard is called when there is a need to increase the overall capacity of a stream because of an expected increase in the volume of data records being ingested.
    You can also use SplitShard when a shard appears to be approaching its maximum utilization; for example, the producers sending data into the specific shard are suddenly sending more than previously anticipated. You can also call SplitShard to increase stream capacity, so that more Amazon Kinesis applications can simultaneously read data from the stream for real-time processing.
    You must specify the shard to be split and the new hash key, which is the position in the shard where the shard gets split in two. In many cases, the new hash key might simply be the average of the beginning and ending hash key, but it can be any hash key value in the range being mapped into the shard. For more information about splitting shards, see Split a Shard in the Amazon Kinesis Streams Developer Guide .
    You can use  DescribeStream to determine the shard ID and hash key values for the ShardToSplit and NewStartingHashKey parameters that are specified in the SplitShard request.
    You can use DescribeStream to check the status of the stream, which is returned in StreamStatus . If the stream is in the ACTIVE state, you can call SplitShard . If a stream is in CREATING or UPDATING or DELETING states, DescribeStream returns a ResourceInUseException .
    If the specified stream does not exist, DescribeStream returns a ResourceNotFoundException . If you try to create more shards than are authorized for your account, you receive a LimitExceededException .
    For the default shard limit for an AWS account, see Streams Limits in the Amazon Kinesis Streams Developer Guide . If you need to increase this limit, contact AWS Support .
    If you try to operate on too many streams simultaneously using  CreateStream ,  DeleteStream ,  MergeShards , and/or  SplitShard , you receive a LimitExceededException .
    See also: AWS API Documentation
    
    
    :example: response = client.split_shard(
        StreamName='string',
        ShardToSplit='string',
        NewStartingHashKey='string'
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream for the shard split.
            

    :type ShardToSplit: string
    :param ShardToSplit: [REQUIRED]
            The shard ID of the shard to split.
            

    :type NewStartingHashKey: string
    :param NewStartingHashKey: [REQUIRED]
            A hash key value for the starting hash key of one of the child shards created by the split. The hash key range for a given shard constitutes a set of ordered contiguous positive integers. The value for NewStartingHashKey must be in the range of hash keys being mapped into the shard. The NewStartingHashKey hash key value and all higher hash key values in hash key range are distributed to one of the child shards. All the lower hash key values in the range are distributed to the other child shard.
            

    """
    pass

def update_shard_count(StreamName=None, TargetShardCount=None, ScalingType=None):
    """
    Updates the shard count of the specified stream to the specified number of shards.
    Updating the shard count is an asynchronous operation. Upon receiving the request, Amazon Kinesis returns immediately and sets the status of the stream to UPDATING . After the update is complete, Amazon Kinesis sets the status of the stream back to ACTIVE . Depending on the size of the stream, the scaling action could take a few minutes to complete. You can continue to read and write data to your stream while its status is UPDATING .
    To update the shard count, Amazon Kinesis performs splits and merges and individual shards. This can cause short-lived shards to be created, in addition to the final shards. We recommend that you double or halve the shard count, as this results in the fewest number of splits or merges.
    This operation has a rate limit of twice per rolling 24 hour period. You cannot scale above double your current shard count, scale below half your current shard count, or exceed the shard limits for your account.
    For the default limits for an AWS account, see Streams Limits in the Amazon Kinesis Streams Developer Guide . If you need to increase a limit, contact AWS Support .
    See also: AWS API Documentation
    
    
    :example: response = client.update_shard_count(
        StreamName='string',
        TargetShardCount=123,
        ScalingType='UNIFORM_SCALING'
    )
    
    
    :type StreamName: string
    :param StreamName: [REQUIRED]
            The name of the stream.
            

    :type TargetShardCount: integer
    :param TargetShardCount: [REQUIRED]
            The new number of shards.
            

    :type ScalingType: string
    :param ScalingType: [REQUIRED]
            The scaling type. Uniform scaling creates shards of equal size.
            

    :rtype: dict
    :return: {
        'StreamName': 'string',
        'CurrentShardCount': 123,
        'TargetShardCount': 123
    }
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def post_content(botName=None, botAlias=None, userId=None, sessionAttributes=None, contentType=None, accept=None, inputStream=None):
    """
    Sends user input (text or speech) to Amazon Lex. Clients use this API to send requests to Amazon Lex at runtime. Amazon Lex interprets the user input using the machine learning model that it built for the bot.
    In response, Amazon Lex returns the next message to convey to the user. Consider the following example messages:
    Not all Amazon Lex messages require a response from the user. For example, conclusion statements do not require a response. Some messages require only a yes or no response. In addition to the message , Amazon Lex provides additional context about the message in the response that you can use to enhance client behavior, such as displaying the appropriate client user interface. Consider the following examples:
    In addition, Amazon Lex also returns your application-specific sessionAttributes . For more information, see Managing Conversation Context .
    See also: AWS API Documentation
    
    
    :example: response = client.post_content(
        botName='string',
        botAlias='string',
        userId='string',
        sessionAttributes={...}|[...]|123|123.4|'string'|True|None,
        contentType='string',
        accept='string',
        inputStream=b'bytes'|file
    )
    
    
    :type botName: string
    :param botName: [REQUIRED]
            Name of the Amazon Lex bot.
            

    :type botAlias: string
    :param botAlias: [REQUIRED]
            Alias of the Amazon Lex bot.
            

    :type userId: string
    :param userId: [REQUIRED]
            ID of the client application user. Typically, each of your application users should have a unique ID. The application developer decides the user IDs. At runtime, each request must include the user ID. Note the following considerations:
            If you want a user to start conversation on one device and continue the conversation on another device, you might choose a user-specific identifier, such as the user's login, or Amazon Cognito user ID (assuming your application is using Amazon Cognito).
            If you want the same user to be able to have two independent conversations on two different devices, you might choose device-specific identifier, such as device ID, or some globally unique identifier.
            

    :type sessionAttributes: JSON serializable
    :param sessionAttributes: You pass this value in the x-amz-lex-session-attributes HTTP header. The value must be map (keys and values must be strings) that is JSON serialized and then base64 encoded.
            A session represents dialog between a user and Amazon Lex. At runtime, a client application can pass contextual information, in the request to Amazon Lex. For example,
            You might use session attributes to track the requestID of user requests.
            In Getting Started Exercise 1, the example bot uses the price session attribute to maintain the price of flowers ordered (for example, 'price':25). The code hook (Lambda function) sets this attribute based on the type of flowers ordered. For more information, see Review the Details of Information Flow .
            In the BookTrip bot exercise, the bot uses the currentReservation session attribute to maintains the slot data during the in-progress conversation to book a hotel or book a car. For more information, see Details of Information Flow .
            Amazon Lex passes these session attributes to the Lambda functions configured for the intent In the your Lambda function, you can use the session attributes for initialization and customization (prompts). Some examples are:
            Initialization - In a pizza ordering bot, if you pass user location (for example, 'Location : 111 Maple Street' ), then your Lambda function might use this information to determine the closest pizzeria to place the order (and perhaps set the storeAddress slot value as well). Personalized prompts - For example, you can configure prompts to refer to the user by name (for example, 'Hey [firstName], what toppings would you like?'). You can pass the user's name as a session attribute ('firstName': 'Joe') so that Amazon Lex can substitute the placeholder to provide a personalized prompt to the user ('Hey Joe, what toppings would you like?').
            Note
            Amazon Lex does not persist session attributes.
            If you configured a code hook for the intent, Amazon Lex passes the incoming session attributes to the Lambda function. The Lambda function must return these session attributes if you want Amazon Lex to return them to the client.
            If there is no code hook configured for the intent Amazon Lex simply returns the session attributes to the client application.
            

    :type contentType: string
    :param contentType: [REQUIRED]
            You pass this values as the Content-Type HTTP header.
            Indicates the audio format or text. The header value must start with one of the following prefixes:
            PCM format
            audio/l16; rate=16000; channels=1
            audio/x-l16; sample-rate=16000; channel-count=1
            Opus format
            audio/x-cbr-opus-with-preamble; preamble-size=0; bit-rate=1; frame-size-milliseconds=1.1
            Text format
            text/plain; charset=utf-8
            

    :type accept: string
    :param accept: You pass this value as the Accept HTTP header.
            The message Amazon Lex returns in the response can be either text or speech based on the Accept HTTP header value in the request.
            If the value is text/plain; charset=utf-8 , Amazon Lex returns text in the response.
            If the value begins with audio/ , Amazon Lex returns speech in the response. Amazon Lex uses Amazon Polly to generate the speech (using the configuration you specified in the Accept header). For example, if you specify audio/mpeg as the value, Amazon Lex returns speech in the MPEG format. The following are the accepted values:
            audio/mpeg
            audio/ogg
            audio/pcm
            text/plain; charset=utf-8
            audio/* (defaults to mpeg)
            

    :type inputStream: bytes or seekable file-like object
    :param inputStream: [REQUIRED]
            User input in PCM or Opus audio format or text format as described in the Content-Type HTTP header.
            

    :rtype: dict
    :return: {
        'contentType': 'string',
        'intentName': 'string',
        'slots': {...}|[...]|123|123.4|'string'|True|None,
        'sessionAttributes': {...}|[...]|123|123.4|'string'|True|None,
        'message': 'string',
        'dialogState': 'ElicitIntent'|'ConfirmIntent'|'ElicitSlot'|'Fulfilled'|'ReadyForFulfillment'|'Failed',
        'slotToElicit': 'string',
        'inputTranscript': 'string',
        'audioStream': StreamingBody()
    }
    
    
    :returns: 
    If the message is to elicit slot data, Amazon Lex returns the following context information:
    x-amz-lex-dialog-state header set to ElicitSlot
    x-amz-lex-intent-name header set to the intent name in the current context
    x-amz-lex-slot-to-elicit header set to the slot name for which the message is eliciting information
    x-amz-lex-slots header set to a map of slots configured for the intent with their current values
    
    
    If the message is a confirmation prompt, the x-amz-lex-dialog-state header is set to Confirmation and the x-amz-lex-slot-to-elicit header is omitted.
    If the message is a clarification prompt configured for the intent, indicating that the user intent is not understood, the x-amz-dialog-state header is set to ElicitIntent and the x-amz-slot-to-elicit header is omitted.
    
    """
    pass

def post_text(botName=None, botAlias=None, userId=None, sessionAttributes=None, inputText=None):
    """
    Sends user input (text-only) to Amazon Lex. Client applications can use this API to send requests to Amazon Lex at runtime. Amazon Lex then interprets the user input using the machine learning model it built for the bot.
    In response, Amazon Lex returns the next message to convey to the user an optional responseCard to display. Consider the following example messages:
    Not all Amazon Lex messages require a user response. For example, a conclusion statement does not require a response. Some messages require only a "yes" or "no" user response. In addition to the message , Amazon Lex provides additional context about the message in the response that you might use to enhance client behavior, for example, to display the appropriate client user interface. These are the slotToElicit , dialogState , intentName , and slots fields in the response. Consider the following examples:
    In addition, Amazon Lex also returns your application-specific sessionAttributes . For more information, see Managing Conversation Context .
    See also: AWS API Documentation
    
    
    :example: response = client.post_text(
        botName='string',
        botAlias='string',
        userId='string',
        sessionAttributes={
            'string': 'string'
        },
        inputText='string'
    )
    
    
    :type botName: string
    :param botName: [REQUIRED]
            The name of the Amazon Lex bot.
            

    :type botAlias: string
    :param botAlias: [REQUIRED]
            The alias of the Amazon Lex bot.
            

    :type userId: string
    :param userId: [REQUIRED]
            The ID of the client application user. The application developer decides the user IDs. At runtime, each request must include the user ID. Typically, each of your application users should have a unique ID. Note the following considerations:
            If you want a user to start a conversation on one device and continue the conversation on another device, you might choose a user-specific identifier, such as a login or Amazon Cognito user ID (assuming your application is using Amazon Cognito).
            If you want the same user to be able to have two independent conversations on two different devices, you might choose a device-specific identifier, such as device ID, or some globally unique identifier.
            

    :type sessionAttributes: dict
    :param sessionAttributes: By using session attributes, a client application can pass contextual information in the request to Amazon Lex For example,
            In Getting Started Exercise 1, the example bot uses the price session attribute to maintain the price of the flowers ordered (for example, 'Price':25). The code hook (the Lambda function) sets this attribute based on the type of flowers ordered. For more information, see Review the Details of Information Flow .
            In the BookTrip bot exercise, the bot uses the currentReservation session attribute to maintain slot data during the in-progress conversation to book a hotel or book a car. For more information, see Details of Information Flow .
            You might use the session attributes (key, value pairs) to track the requestID of user requests.
            Amazon Lex simply passes these session attributes to the Lambda functions configured for the intent.
            In your Lambda function, you can also use the session attributes for initialization and customization (prompts and response cards). Some examples are:
            Initialization - In a pizza ordering bot, if you can pass the user location as a session attribute (for example, 'Location' : '111 Maple street' ), then your Lambda function might use this information to determine the closest pizzeria to place the order (perhaps to set the storeAddress slot value).
            Personalize prompts - For example, you can configure prompts to refer to the user name. (For example, 'Hey [FirstName], what toppings would you like?'). You can pass the user name as a session attribute ('FirstName' : 'Joe' ) so that Amazon Lex can substitute the placeholder to provide a personalize prompt to the user ('Hey Joe, what toppings would you like?').
            Note
            Amazon Lex does not persist session attributes.
            If you configure a code hook for the intent, Amazon Lex passes the incoming session attributes to the Lambda function. If you want Amazon Lex to return these session attributes back to the client, the Lambda function must return them.
            If there is no code hook configured for the intent, Amazon Lex simply returns the session attributes back to the client application.
            (string) --
            (string) --
            

    :type inputText: string
    :param inputText: [REQUIRED]
            The text that the user entered (Amazon Lex interprets this text).
            

    :rtype: dict
    :return: {
        'intentName': 'string',
        'slots': {
            'string': 'string'
        },
        'sessionAttributes': {
            'string': 'string'
        },
        'message': 'string',
        'dialogState': 'ElicitIntent'|'ConfirmIntent'|'ElicitSlot'|'Fulfilled'|'ReadyForFulfillment'|'Failed',
        'slotToElicit': 'string',
        'responseCard': {
            'version': 'string',
            'contentType': 'application/vnd.amazonaws.card.generic',
            'genericAttachments': [
                {
                    'title': 'string',
                    'subTitle': 'string',
                    'attachmentLinkUrl': 'string',
                    'imageUrl': 'string',
                    'buttons': [
                        {
                            'text': 'string',
                            'value': 'string'
                        },
                    ]
                },
            ]
        }
    }
    
    
    :returns: 
    If the message is to elicit slot data, Amazon Lex returns the following context information:
    dialogState set to ElicitSlot
    intentName set to the intent name in the current context
    slotToElicit set to the slot name for which the message is eliciting information
    slots set to a map of slots, configured for the intent, with currently known values
    
    
    If the message is a confirmation prompt, the dialogState is set to ConfirmIntent and SlotToElicit is set to null.
    If the message is a clarification prompt (configured for the intent) that indicates that user intent is not understood, the dialogState is set to ElicitIntent and slotToElicit is set to null.
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def add_tags(LoadBalancerNames=None, Tags=None):
    """
    Adds the specified tags to the specified load balancer. Each load balancer can have a maximum of 10 tags.
    Each tag consists of a key and an optional value. If a tag with the same key is already associated with the load balancer, AddTags updates its value.
    For more information, see Tag Your Classic Load Balancer in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example adds two tags to the specified load balancer.
    Expected Output:
    
    :example: response = client.add_tags(
        LoadBalancerNames=[
            'string',
        ],
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerNames: list
    :param LoadBalancerNames: [REQUIRED]
            The name of the load balancer. You can specify one load balancer only.
            (string) --
            

    :type Tags: list
    :param Tags: [REQUIRED]
            The tags.
            (dict) --Information about a tag.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) --The value of the tag.
            
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def apply_security_groups_to_load_balancer(LoadBalancerName=None, SecurityGroups=None):
    """
    Associates one or more security groups with your load balancer in a virtual private cloud (VPC). The specified security groups override the previously associated security groups.
    For more information, see Security Groups for Load Balancers in a VPC in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example associates a security group with the specified load balancer in a VPC.
    Expected Output:
    
    :example: response = client.apply_security_groups_to_load_balancer(
        LoadBalancerName='string',
        SecurityGroups=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type SecurityGroups: list
    :param SecurityGroups: [REQUIRED]
            The IDs of the security groups to associate with the load balancer. Note that you cannot specify the name of the security group.
            (string) --
            

    :rtype: dict
    :return: {
        'SecurityGroups': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def attach_load_balancer_to_subnets(LoadBalancerName=None, Subnets=None):
    """
    Adds one or more subnets to the set of configured subnets for the specified load balancer.
    The load balancer evenly distributes requests across all registered subnets. For more information, see Add or Remove Subnets for Your Load Balancer in a VPC in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example adds the specified subnet to the set of configured subnets for the specified load balancer.
    Expected Output:
    
    :example: response = client.attach_load_balancer_to_subnets(
        LoadBalancerName='string',
        Subnets=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type Subnets: list
    :param Subnets: [REQUIRED]
            The IDs of the subnets to add. You can add only one subnet per Availability Zone.
            (string) --
            

    :rtype: dict
    :return: {
        'Subnets': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    """
    pass

def configure_health_check(LoadBalancerName=None, HealthCheck=None):
    """
    Specifies the health check settings to use when evaluating the health state of your EC2 instances.
    For more information, see Configure Health Checks for Your Load Balancer in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example specifies the health check settings used to evaluate the health of your backend EC2 instances.
    Expected Output:
    
    :example: response = client.configure_health_check(
        LoadBalancerName='string',
        HealthCheck={
            'Target': 'string',
            'Interval': 123,
            'Timeout': 123,
            'UnhealthyThreshold': 123,
            'HealthyThreshold': 123
        }
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type HealthCheck: dict
    :param HealthCheck: [REQUIRED]
            The configuration information.
            Target (string) -- [REQUIRED]The instance being checked. The protocol is either TCP, HTTP, HTTPS, or SSL. The range of valid ports is one (1) through 65535.
            TCP is the default, specified as a TCP: port pair, for example 'TCP:5000'. In this case, a health check simply attempts to open a TCP connection to the instance on the specified port. Failure to connect within the configured timeout is considered unhealthy.
            SSL is also specified as SSL: port pair, for example, SSL:5000.
            For HTTP/HTTPS, you must include a ping path in the string. HTTP is specified as a HTTP:port;/;PathToPing; grouping, for example 'HTTP:80/weather/us/wa/seattle'. In this case, a HTTP GET request is issued to the instance on the given port and path. Any answer other than '200 OK' within the timeout period is considered unhealthy.
            The total length of the HTTP ping target must be 1024 16-bit Unicode characters or less.
            Interval (integer) -- [REQUIRED]The approximate interval, in seconds, between health checks of an individual instance.
            Timeout (integer) -- [REQUIRED]The amount of time, in seconds, during which no response means a failed health check.
            This value must be less than the Interval value.
            UnhealthyThreshold (integer) -- [REQUIRED]The number of consecutive health check failures required before moving the instance to the Unhealthy state.
            HealthyThreshold (integer) -- [REQUIRED]The number of consecutive health checks successes required before moving the instance to the Healthy state.
            

    :rtype: dict
    :return: {
        'HealthCheck': {
            'Target': 'string',
            'Interval': 123,
            'Timeout': 123,
            'UnhealthyThreshold': 123,
            'HealthyThreshold': 123
        }
    }
    
    
    """
    pass

def create_app_cookie_stickiness_policy(LoadBalancerName=None, PolicyName=None, CookieName=None):
    """
    Generates a stickiness policy with sticky session lifetimes that follow that of an application-generated cookie. This policy can be associated only with HTTP/HTTPS listeners.
    This policy is similar to the policy created by  CreateLBCookieStickinessPolicy , except that the lifetime of the special Elastic Load Balancing cookie, AWSELB , follows the lifetime of the application-generated cookie specified in the policy configuration. The load balancer only inserts a new stickiness cookie when the application response includes a new application cookie.
    If the application cookie is explicitly removed or expires, the session stops being sticky until a new application cookie is issued.
    For more information, see Application-Controlled Session Stickiness in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example generates a stickiness policy that follows the sticky session lifetimes of the application-generated cookie.
    Expected Output:
    
    :example: response = client.create_app_cookie_stickiness_policy(
        LoadBalancerName='string',
        PolicyName='string',
        CookieName='string'
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type PolicyName: string
    :param PolicyName: [REQUIRED]
            The name of the policy being created. Policy names must consist of alphanumeric characters and dashes (-). This name must be unique within the set of policies for this load balancer.
            

    :type CookieName: string
    :param CookieName: [REQUIRED]
            The name of the application cookie used for stickiness.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def create_lb_cookie_stickiness_policy(LoadBalancerName=None, PolicyName=None, CookieExpirationPeriod=None):
    """
    Generates a stickiness policy with sticky session lifetimes controlled by the lifetime of the browser (user-agent) or a specified expiration period. This policy can be associated only with HTTP/HTTPS listeners.
    When a load balancer implements this policy, the load balancer uses a special cookie to track the instance for each request. When the load balancer receives a request, it first checks to see if this cookie is present in the request. If so, the load balancer sends the request to the application server specified in the cookie. If not, the load balancer sends the request to a server that is chosen based on the existing load-balancing algorithm.
    A cookie is inserted into the response for binding subsequent requests from the same user to that server. The validity of the cookie is based on the cookie expiration time, which is specified in the policy configuration.
    For more information, see Duration-Based Session Stickiness in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example generates a stickiness policy with sticky session lifetimes controlled by the specified expiration period.
    Expected Output:
    
    :example: response = client.create_lb_cookie_stickiness_policy(
        LoadBalancerName='string',
        PolicyName='string',
        CookieExpirationPeriod=123
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type PolicyName: string
    :param PolicyName: [REQUIRED]
            The name of the policy being created. Policy names must consist of alphanumeric characters and dashes (-). This name must be unique within the set of policies for this load balancer.
            

    :type CookieExpirationPeriod: integer
    :param CookieExpirationPeriod: The time period, in seconds, after which the cookie should be considered stale. If you do not specify this parameter, the default value is 0, which indicates that the sticky session should last for the duration of the browser session.

    :rtype: dict
    :return: {}
    
    
    """
    pass

def create_load_balancer(LoadBalancerName=None, Listeners=None, AvailabilityZones=None, Subnets=None, SecurityGroups=None, Scheme=None, Tags=None):
    """
    Creates a Classic Load Balancer.
    You can add listeners, security groups, subnets, and tags when you create your load balancer, or you can add them later using  CreateLoadBalancerListeners ,  ApplySecurityGroupsToLoadBalancer ,  AttachLoadBalancerToSubnets , and  AddTags .
    To describe your current load balancers, see  DescribeLoadBalancers . When you are finished with a load balancer, you can delete it using  DeleteLoadBalancer .
    You can create up to 20 load balancers per region per account. You can request an increase for the number of load balancers for your account. For more information, see Limits for Your Classic Load Balancer in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example creates a load balancer with an HTTP listener in a VPC.
    Expected Output:
    This example creates a load balancer with an HTTP listener in EC2-Classic.
    Expected Output:
    This example creates a load balancer with an HTTPS listener in a VPC.
    Expected Output:
    This example creates a load balancer with an HTTPS listener in EC2-Classic.
    Expected Output:
    This example creates an internal load balancer with an HTTP listener in a VPC.
    Expected Output:
    
    :example: response = client.create_load_balancer(
        LoadBalancerName='string',
        Listeners=[
            {
                'Protocol': 'string',
                'LoadBalancerPort': 123,
                'InstanceProtocol': 'string',
                'InstancePort': 123,
                'SSLCertificateId': 'string'
            },
        ],
        AvailabilityZones=[
            'string',
        ],
        Subnets=[
            'string',
        ],
        SecurityGroups=[
            'string',
        ],
        Scheme='string',
        Tags=[
            {
                'Key': 'string',
                'Value': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            This name must be unique within your set of load balancers for the region, must have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, and cannot begin or end with a hyphen.
            

    :type Listeners: list
    :param Listeners: [REQUIRED]
            The listeners.
            For more information, see Listeners for Your Classic Load Balancer in the Classic Load Balancer Guide .
            (dict) --Information about a listener.
            For information about the protocols and the ports supported by Elastic Load Balancing, see Listeners for Your Classic Load Balancer in the Classic Load Balancer Guide .
            Protocol (string) -- [REQUIRED]The load balancer transport protocol to use for routing: HTTP, HTTPS, TCP, or SSL.
            LoadBalancerPort (integer) -- [REQUIRED]The port on which the load balancer is listening. On EC2-VPC, you can specify any port from the range 1-65535. On EC2-Classic, you can specify any port from the following list: 25, 80, 443, 465, 587, 1024-65535.
            InstanceProtocol (string) --The protocol to use for routing traffic to instances: HTTP, HTTPS, TCP, or SSL.
            If the front-end protocol is HTTP, HTTPS, TCP, or SSL, InstanceProtocol must be at the same protocol.
            If there is another listener with the same InstancePort whose InstanceProtocol is secure, (HTTPS or SSL), the listener's InstanceProtocol must also be secure.
            If there is another listener with the same InstancePort whose InstanceProtocol is HTTP or TCP, the listener's InstanceProtocol must be HTTP or TCP.
            InstancePort (integer) -- [REQUIRED]The port on which the instance is listening.
            SSLCertificateId (string) --The Amazon Resource Name (ARN) of the server certificate.
            
            

    :type AvailabilityZones: list
    :param AvailabilityZones: One or more Availability Zones from the same region as the load balancer.
            You must specify at least one Availability Zone.
            You can add more Availability Zones after you create the load balancer using EnableAvailabilityZonesForLoadBalancer .
            (string) --
            

    :type Subnets: list
    :param Subnets: The IDs of the subnets in your VPC to attach to the load balancer. Specify one subnet per Availability Zone specified in AvailabilityZones .
            (string) --
            

    :type SecurityGroups: list
    :param SecurityGroups: The IDs of the security groups to assign to the load balancer.
            (string) --
            

    :type Scheme: string
    :param Scheme: The type of a load balancer. Valid only for load balancers in a VPC.
            By default, Elastic Load Balancing creates an Internet-facing load balancer with a DNS name that resolves to public IP addresses. For more information about Internet-facing and Internal load balancers, see Load Balancer Scheme in the Elastic Load Balancing User Guide .
            Specify internal to create a load balancer with a DNS name that resolves to private IP addresses.
            

    :type Tags: list
    :param Tags: A list of tags to assign to the load balancer.
            For more information about tagging your load balancer, see Tag Your Classic Load Balancer in the Classic Load Balancer Guide .
            (dict) --Information about a tag.
            Key (string) -- [REQUIRED]The key of the tag.
            Value (string) --The value of the tag.
            
            

    :rtype: dict
    :return: {
        'DNSName': 'string'
    }
    
    
    """
    pass

def create_load_balancer_listeners(LoadBalancerName=None, Listeners=None):
    """
    Creates one or more listeners for the specified load balancer. If a listener with the specified port does not already exist, it is created; otherwise, the properties of the new listener must match the properties of the existing listener.
    For more information, see Listeners for Your Classic Load Balancer in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example creates a listener for your load balancer at port 80 using the HTTP protocol.
    Expected Output:
    This example creates a listener for your load balancer at port 443 using the HTTPS protocol.
    Expected Output:
    
    :example: response = client.create_load_balancer_listeners(
        LoadBalancerName='string',
        Listeners=[
            {
                'Protocol': 'string',
                'LoadBalancerPort': 123,
                'InstanceProtocol': 'string',
                'InstancePort': 123,
                'SSLCertificateId': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type Listeners: list
    :param Listeners: [REQUIRED]
            The listeners.
            (dict) --Information about a listener.
            For information about the protocols and the ports supported by Elastic Load Balancing, see Listeners for Your Classic Load Balancer in the Classic Load Balancer Guide .
            Protocol (string) -- [REQUIRED]The load balancer transport protocol to use for routing: HTTP, HTTPS, TCP, or SSL.
            LoadBalancerPort (integer) -- [REQUIRED]The port on which the load balancer is listening. On EC2-VPC, you can specify any port from the range 1-65535. On EC2-Classic, you can specify any port from the following list: 25, 80, 443, 465, 587, 1024-65535.
            InstanceProtocol (string) --The protocol to use for routing traffic to instances: HTTP, HTTPS, TCP, or SSL.
            If the front-end protocol is HTTP, HTTPS, TCP, or SSL, InstanceProtocol must be at the same protocol.
            If there is another listener with the same InstancePort whose InstanceProtocol is secure, (HTTPS or SSL), the listener's InstanceProtocol must also be secure.
            If there is another listener with the same InstancePort whose InstanceProtocol is HTTP or TCP, the listener's InstanceProtocol must be HTTP or TCP.
            InstancePort (integer) -- [REQUIRED]The port on which the instance is listening.
            SSLCertificateId (string) --The Amazon Resource Name (ARN) of the server certificate.
            
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def create_load_balancer_policy(LoadBalancerName=None, PolicyName=None, PolicyTypeName=None, PolicyAttributes=None):
    """
    Creates a policy with the specified attributes for the specified load balancer.
    Policies are settings that are saved for your load balancer and that can be applied to the listener or the application server, depending on the policy type.
    See also: AWS API Documentation
    
    Examples
    This example creates a policy that enables Proxy Protocol on the specified load balancer.
    Expected Output:
    This example creates a public key policy.
    Expected Output:
    This example creates a backend server authentication policy that enables authentication on your backend instance using a public key policy.
    Expected Output:
    
    :example: response = client.create_load_balancer_policy(
        LoadBalancerName='string',
        PolicyName='string',
        PolicyTypeName='string',
        PolicyAttributes=[
            {
                'AttributeName': 'string',
                'AttributeValue': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type PolicyName: string
    :param PolicyName: [REQUIRED]
            The name of the load balancer policy to be created. This name must be unique within the set of policies for this load balancer.
            

    :type PolicyTypeName: string
    :param PolicyTypeName: [REQUIRED]
            The name of the base policy type. To get the list of policy types, use DescribeLoadBalancerPolicyTypes .
            

    :type PolicyAttributes: list
    :param PolicyAttributes: The policy attributes.
            (dict) --Information about a policy attribute.
            AttributeName (string) --The name of the attribute.
            AttributeValue (string) --The value of the attribute.
            
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def delete_load_balancer(LoadBalancerName=None):
    """
    Deletes the specified load balancer.
    If you are attempting to recreate a load balancer, you must reconfigure all settings. The DNS name associated with a deleted load balancer are no longer usable. The name and associated DNS record of the deleted load balancer no longer exist and traffic sent to any of its IP addresses is no longer delivered to your instances.
    If the load balancer does not exist or has already been deleted, the call to DeleteLoadBalancer still succeeds.
    See also: AWS API Documentation
    
    Examples
    This example deletes the specified load balancer.
    Expected Output:
    
    :example: response = client.delete_load_balancer(
        LoadBalancerName='string'
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def delete_load_balancer_listeners(LoadBalancerName=None, LoadBalancerPorts=None):
    """
    Deletes the specified listeners from the specified load balancer.
    See also: AWS API Documentation
    
    Examples
    This example deletes the listener for the specified port from the specified load balancer.
    Expected Output:
    
    :example: response = client.delete_load_balancer_listeners(
        LoadBalancerName='string',
        LoadBalancerPorts=[
            123,
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type LoadBalancerPorts: list
    :param LoadBalancerPorts: [REQUIRED]
            The client port numbers of the listeners.
            (integer) --
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def delete_load_balancer_policy(LoadBalancerName=None, PolicyName=None):
    """
    Deletes the specified policy from the specified load balancer. This policy must not be enabled for any listeners.
    See also: AWS API Documentation
    
    Examples
    This example deletes the specified policy from the specified load balancer. The policy must not be enabled on any listener.
    Expected Output:
    
    :example: response = client.delete_load_balancer_policy(
        LoadBalancerName='string',
        PolicyName='string'
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type PolicyName: string
    :param PolicyName: [REQUIRED]
            The name of the policy.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def deregister_instances_from_load_balancer(LoadBalancerName=None, Instances=None):
    """
    Deregisters the specified instances from the specified load balancer. After the instance is deregistered, it no longer receives traffic from the load balancer.
    You can use  DescribeLoadBalancers to verify that the instance is deregistered from the load balancer.
    For more information, see Register or De-Register EC2 Instances in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example deregisters the specified instance from the specified load balancer.
    Expected Output:
    
    :example: response = client.deregister_instances_from_load_balancer(
        LoadBalancerName='string',
        Instances=[
            {
                'InstanceId': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type Instances: list
    :param Instances: [REQUIRED]
            The IDs of the instances.
            (dict) --The ID of an EC2 instance.
            InstanceId (string) --The instance ID.
            
            

    :rtype: dict
    :return: {
        'Instances': [
            {
                'InstanceId': 'string'
            },
        ]
    }
    
    
    """
    pass

def describe_account_limits(Marker=None, PageSize=None):
    """
    Describes the current Elastic Load Balancing resource limits for your AWS account.
    For more information, see Limits for Your Classic Load Balancer in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    
    :example: response = client.describe_account_limits(
        Marker='string',
        PageSize=123
    )
    
    
    :type Marker: string
    :param Marker: The marker for the next set of results. (You received this marker from a previous call.)

    :type PageSize: integer
    :param PageSize: The maximum number of results to return with this call.

    :rtype: dict
    :return: {
        'Limits': [
            {
                'Name': 'string',
                'Max': 'string'
            },
        ],
        'NextMarker': 'string'
    }
    
    
    :returns: 
    classic-listeners
    classic-load-balancers
    
    """
    pass

def describe_instance_health(LoadBalancerName=None, Instances=None):
    """
    Describes the state of the specified instances with respect to the specified load balancer. If no instances are specified, the call describes the state of all instances that are currently registered with the load balancer. If instances are specified, their state is returned even if they are no longer registered with the load balancer. The state of terminated instances is not returned.
    See also: AWS API Documentation
    
    Examples
    This example describes the health of the instances for the specified load balancer.
    Expected Output:
    
    :example: response = client.describe_instance_health(
        LoadBalancerName='string',
        Instances=[
            {
                'InstanceId': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type Instances: list
    :param Instances: The IDs of the instances.
            (dict) --The ID of an EC2 instance.
            InstanceId (string) --The instance ID.
            
            

    :rtype: dict
    :return: {
        'InstanceStates': [
            {
                'InstanceId': 'string',
                'State': 'string',
                'ReasonCode': 'string',
                'Description': 'string'
            },
        ]
    }
    
    
    :returns: 
    N/A
    A transient error occurred. Please try again later.
    Instance has failed at least the UnhealthyThreshold number of health checks consecutively.
    Instance has not passed the configured HealthyThreshold number of health checks consecutively.
    Instance registration is still in progress.
    Instance is in the EC2 Availability Zone for which LoadBalancer is not configured to route traffic to.
    Instance is not currently registered with the LoadBalancer.
    Instance deregistration currently in progress.
    Disable Availability Zone is currently in progress.
    Instance is in pending state.
    Instance is in stopped state.
    Instance is in terminated state.
    
    """
    pass

def describe_load_balancer_attributes(LoadBalancerName=None):
    """
    Describes the attributes for the specified load balancer.
    See also: AWS API Documentation
    
    Examples
    This example describes the attributes of the specified load balancer.
    Expected Output:
    
    :example: response = client.describe_load_balancer_attributes(
        LoadBalancerName='string'
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :rtype: dict
    :return: {
        'LoadBalancerAttributes': {
            'CrossZoneLoadBalancing': {
                'Enabled': True|False
            },
            'AccessLog': {
                'Enabled': True|False,
                'S3BucketName': 'string',
                'EmitInterval': 123,
                'S3BucketPrefix': 'string'
            },
            'ConnectionDraining': {
                'Enabled': True|False,
                'Timeout': 123
            },
            'ConnectionSettings': {
                'IdleTimeout': 123
            },
            'AdditionalAttributes': [
                {
                    'Key': 'string',
                    'Value': 'string'
                },
            ]
        }
    }
    
    
    """
    pass

def describe_load_balancer_policies(LoadBalancerName=None, PolicyNames=None):
    """
    Describes the specified policies.
    If you specify a load balancer name, the action returns the descriptions of all policies created for the load balancer. If you specify a policy name associated with your load balancer, the action returns the description of that policy. If you don't specify a load balancer name, the action returns descriptions of the specified sample policies, or descriptions of all sample policies. The names of the sample policies have the ELBSample- prefix.
    See also: AWS API Documentation
    
    Examples
    This example describes the specified policy associated with the specified load balancer.
    Expected Output:
    
    :example: response = client.describe_load_balancer_policies(
        LoadBalancerName='string',
        PolicyNames=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: The name of the load balancer.

    :type PolicyNames: list
    :param PolicyNames: The names of the policies.
            (string) --
            

    :rtype: dict
    :return: {
        'PolicyDescriptions': [
            {
                'PolicyName': 'string',
                'PolicyTypeName': 'string',
                'PolicyAttributeDescriptions': [
                    {
                        'AttributeName': 'string',
                        'AttributeValue': 'string'
                    },
                ]
            },
        ]
    }
    
    
    """
    pass

def describe_load_balancer_policy_types(PolicyTypeNames=None):
    """
    Describes the specified load balancer policy types or all load balancer policy types.
    The description of each type indicates how it can be used. For example, some policies can be used only with layer 7 listeners, some policies can be used only with layer 4 listeners, and some policies can be used only with your EC2 instances.
    You can use  CreateLoadBalancerPolicy to create a policy configuration for any of these policy types. Then, depending on the policy type, use either  SetLoadBalancerPoliciesOfListener or  SetLoadBalancerPoliciesForBackendServer to set the policy.
    See also: AWS API Documentation
    
    Examples
    This example describes the specified load balancer policy type.
    Expected Output:
    
    :example: response = client.describe_load_balancer_policy_types(
        PolicyTypeNames=[
            'string',
        ]
    )
    
    
    :type PolicyTypeNames: list
    :param PolicyTypeNames: The names of the policy types. If no names are specified, describes all policy types defined by Elastic Load Balancing.
            (string) --
            

    :rtype: dict
    :return: {
        'PolicyTypeDescriptions': [
            {
                'PolicyTypeName': 'string',
                'Description': 'string',
                'PolicyAttributeTypeDescriptions': [
                    {
                        'AttributeName': 'string',
                        'AttributeType': 'string',
                        'Description': 'string',
                        'DefaultValue': 'string',
                        'Cardinality': 'string'
                    },
                ]
            },
        ]
    }
    
    
    :returns: 
    ONE(1) : Single value required
    ZERO_OR_ONE(0..1) : Up to one value is allowed
    ZERO_OR_MORE(0..*) : Optional. Multiple values are allowed
    ONE_OR_MORE(1..*0) : Required. Multiple values are allowed
    
    """
    pass

def describe_load_balancers(LoadBalancerNames=None, Marker=None, PageSize=None):
    """
    Describes the specified the load balancers. If no load balancers are specified, the call describes all of your load balancers.
    See also: AWS API Documentation
    
    Examples
    This example describes the specified load balancer.
    Expected Output:
    
    :example: response = client.describe_load_balancers(
        LoadBalancerNames=[
            'string',
        ],
        Marker='string',
        PageSize=123
    )
    
    
    :type LoadBalancerNames: list
    :param LoadBalancerNames: The names of the load balancers.
            (string) --
            

    :type Marker: string
    :param Marker: The marker for the next set of results. (You received this marker from a previous call.)

    :type PageSize: integer
    :param PageSize: The maximum number of results to return with this call (a number from 1 to 400). The default is 400.

    :rtype: dict
    :return: {
        'LoadBalancerDescriptions': [
            {
                'LoadBalancerName': 'string',
                'DNSName': 'string',
                'CanonicalHostedZoneName': 'string',
                'CanonicalHostedZoneNameID': 'string',
                'ListenerDescriptions': [
                    {
                        'Listener': {
                            'Protocol': 'string',
                            'LoadBalancerPort': 123,
                            'InstanceProtocol': 'string',
                            'InstancePort': 123,
                            'SSLCertificateId': 'string'
                        },
                        'PolicyNames': [
                            'string',
                        ]
                    },
                ],
                'Policies': {
                    'AppCookieStickinessPolicies': [
                        {
                            'PolicyName': 'string',
                            'CookieName': 'string'
                        },
                    ],
                    'LBCookieStickinessPolicies': [
                        {
                            'PolicyName': 'string',
                            'CookieExpirationPeriod': 123
                        },
                    ],
                    'OtherPolicies': [
                        'string',
                    ]
                },
                'BackendServerDescriptions': [
                    {
                        'InstancePort': 123,
                        'PolicyNames': [
                            'string',
                        ]
                    },
                ],
                'AvailabilityZones': [
                    'string',
                ],
                'Subnets': [
                    'string',
                ],
                'VPCId': 'string',
                'Instances': [
                    {
                        'InstanceId': 'string'
                    },
                ],
                'HealthCheck': {
                    'Target': 'string',
                    'Interval': 123,
                    'Timeout': 123,
                    'UnhealthyThreshold': 123,
                    'HealthyThreshold': 123
                },
                'SourceSecurityGroup': {
                    'OwnerAlias': 'string',
                    'GroupName': 'string'
                },
                'SecurityGroups': [
                    'string',
                ],
                'CreatedTime': datetime(2015, 1, 1),
                'Scheme': 'string'
            },
        ],
        'NextMarker': 'string'
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def describe_tags(LoadBalancerNames=None):
    """
    Describes the tags associated with the specified load balancers.
    See also: AWS API Documentation
    
    Examples
    This example describes the tags for the specified load balancer.
    Expected Output:
    
    :example: response = client.describe_tags(
        LoadBalancerNames=[
            'string',
        ]
    )
    
    
    :type LoadBalancerNames: list
    :param LoadBalancerNames: [REQUIRED]
            The names of the load balancers.
            (string) --
            

    :rtype: dict
    :return: {
        'TagDescriptions': [
            {
                'LoadBalancerName': 'string',
                'Tags': [
                    {
                        'Key': 'string',
                        'Value': 'string'
                    },
                ]
            },
        ]
    }
    
    
    """
    pass

def detach_load_balancer_from_subnets(LoadBalancerName=None, Subnets=None):
    """
    Removes the specified subnets from the set of configured subnets for the load balancer.
    After a subnet is removed, all EC2 instances registered with the load balancer in the removed subnet go into the OutOfService state. Then, the load balancer balances the traffic among the remaining routable subnets.
    See also: AWS API Documentation
    
    Examples
    This example detaches the specified load balancer from the specified subnet.
    Expected Output:
    
    :example: response = client.detach_load_balancer_from_subnets(
        LoadBalancerName='string',
        Subnets=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type Subnets: list
    :param Subnets: [REQUIRED]
            The IDs of the subnets.
            (string) --
            

    :rtype: dict
    :return: {
        'Subnets': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def disable_availability_zones_for_load_balancer(LoadBalancerName=None, AvailabilityZones=None):
    """
    Removes the specified Availability Zones from the set of Availability Zones for the specified load balancer.
    There must be at least one Availability Zone registered with a load balancer at all times. After an Availability Zone is removed, all instances registered with the load balancer that are in the removed Availability Zone go into the OutOfService state. Then, the load balancer attempts to equally balance the traffic among its remaining Availability Zones.
    For more information, see Add or Remove Availability Zones in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example removes the specified Availability Zone from the set of Availability Zones for the specified load balancer.
    Expected Output:
    
    :example: response = client.disable_availability_zones_for_load_balancer(
        LoadBalancerName='string',
        AvailabilityZones=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type AvailabilityZones: list
    :param AvailabilityZones: [REQUIRED]
            The Availability Zones.
            (string) --
            

    :rtype: dict
    :return: {
        'AvailabilityZones': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def enable_availability_zones_for_load_balancer(LoadBalancerName=None, AvailabilityZones=None):
    """
    Adds the specified Availability Zones to the set of Availability Zones for the specified load balancer.
    The load balancer evenly distributes requests across all its registered Availability Zones that contain instances.
    For more information, see Add or Remove Availability Zones in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example adds the specified Availability Zone to the specified load balancer.
    Expected Output:
    
    :example: response = client.enable_availability_zones_for_load_balancer(
        LoadBalancerName='string',
        AvailabilityZones=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type AvailabilityZones: list
    :param AvailabilityZones: [REQUIRED]
            The Availability Zones. These must be in the same region as the load balancer.
            (string) --
            

    :rtype: dict
    :return: {
        'AvailabilityZones': [
            'string',
        ]
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to
            ClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid
            for. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By
            default, the http method is whatever is used in the method's model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name
            as the method name on the client. For example, if the
            method name is create_foo, and you'd normally invoke the
            operation as client.create_foo(**kwargs), if the
            create_foo operation can be paginated, you can use the
            call client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
    """
    pass

def get_waiter():
    """
    
    """
    pass

def modify_load_balancer_attributes(LoadBalancerName=None, LoadBalancerAttributes=None):
    """
    Modifies the attributes of the specified load balancer.
    You can modify the load balancer attributes, such as AccessLogs , ConnectionDraining , and CrossZoneLoadBalancing by either enabling or disabling them. Or, you can modify the load balancer attribute ConnectionSettings by specifying an idle connection timeout value for your load balancer.
    For more information, see the following in the Classic Load Balancer Guide :
    See also: AWS API Documentation
    
    Examples
    This example enables cross-zone load balancing for the specified load balancer.
    Expected Output:
    This example enables connection draining for the specified load balancer.
    Expected Output:
    
    :example: response = client.modify_load_balancer_attributes(
        LoadBalancerName='string',
        LoadBalancerAttributes={
            'CrossZoneLoadBalancing': {
                'Enabled': True|False
            },
            'AccessLog': {
                'Enabled': True|False,
                'S3BucketName': 'string',
                'EmitInterval': 123,
                'S3BucketPrefix': 'string'
            },
            'ConnectionDraining': {
                'Enabled': True|False,
                'Timeout': 123
            },
            'ConnectionSettings': {
                'IdleTimeout': 123
            },
            'AdditionalAttributes': [
                {
                    'Key': 'string',
                    'Value': 'string'
                },
            ]
        }
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type LoadBalancerAttributes: dict
    :param LoadBalancerAttributes: [REQUIRED]
            The attributes for the load balancer.
            CrossZoneLoadBalancing (dict) --If enabled, the load balancer routes the request traffic evenly across all instances regardless of the Availability Zones.
            For more information, see Configure Cross-Zone Load Balancing in the Classic Load Balancer Guide .
            Enabled (boolean) -- [REQUIRED]Specifies whether cross-zone load balancing is enabled for the load balancer.
            AccessLog (dict) --If enabled, the load balancer captures detailed information of all requests and delivers the information to the Amazon S3 bucket that you specify.
            For more information, see Enable Access Logs in the Classic Load Balancer Guide .
            Enabled (boolean) -- [REQUIRED]Specifies whether access logs are enabled for the load balancer.
            S3BucketName (string) --The name of the Amazon S3 bucket where the access logs are stored.
            EmitInterval (integer) --The interval for publishing the access logs. You can specify an interval of either 5 minutes or 60 minutes.
            Default: 60 minutes
            S3BucketPrefix (string) --The logical hierarchy you created for your Amazon S3 bucket, for example my-bucket-prefix/prod . If the prefix is not provided, the log is placed at the root level of the bucket.
            ConnectionDraining (dict) --If enabled, the load balancer allows existing requests to complete before the load balancer shifts traffic away from a deregistered or unhealthy instance.
            For more information, see Configure Connection Draining in the Classic Load Balancer Guide .
            Enabled (boolean) -- [REQUIRED]Specifies whether connection draining is enabled for the load balancer.
            Timeout (integer) --The maximum time, in seconds, to keep the existing connections open before deregistering the instances.
            ConnectionSettings (dict) --If enabled, the load balancer allows the connections to remain idle (no data is sent over the connection) for the specified duration.
            By default, Elastic Load Balancing maintains a 60-second idle connection timeout for both front-end and back-end connections of your load balancer. For more information, see Configure Idle Connection Timeout in the Classic Load Balancer Guide .
            IdleTimeout (integer) -- [REQUIRED]The time, in seconds, that the connection is allowed to be idle (no data has been sent over the connection) before it is closed by the load balancer.
            AdditionalAttributes (list) --This parameter is reserved.
            (dict) --This data type is reserved.
            Key (string) --This parameter is reserved.
            Value (string) --This parameter is reserved.
            
            

    :rtype: dict
    :return: {
        'LoadBalancerName': 'string',
        'LoadBalancerAttributes': {
            'CrossZoneLoadBalancing': {
                'Enabled': True|False
            },
            'AccessLog': {
                'Enabled': True|False,
                'S3BucketName': 'string',
                'EmitInterval': 123,
                'S3BucketPrefix': 'string'
            },
            'ConnectionDraining': {
                'Enabled': True|False,
                'Timeout': 123
            },
            'ConnectionSettings': {
                'IdleTimeout': 123
            },
            'AdditionalAttributes': [
                {
                    'Key': 'string',
                    'Value': 'string'
                },
            ]
        }
    }
    
    
    :returns: 
    LoadBalancerName (string) -- [REQUIRED]
    The name of the load balancer.
    
    LoadBalancerAttributes (dict) -- [REQUIRED]
    The attributes for the load balancer.
    
    CrossZoneLoadBalancing (dict) --If enabled, the load balancer routes the request traffic evenly across all instances regardless of the Availability Zones.
    For more information, see Configure Cross-Zone Load Balancing in the Classic Load Balancer Guide .
    
    Enabled (boolean) -- [REQUIRED]Specifies whether cross-zone load balancing is enabled for the load balancer.
    
    
    
    AccessLog (dict) --If enabled, the load balancer captures detailed information of all requests and delivers the information to the Amazon S3 bucket that you specify.
    For more information, see Enable Access Logs in the Classic Load Balancer Guide .
    
    Enabled (boolean) -- [REQUIRED]Specifies whether access logs are enabled for the load balancer.
    
    S3BucketName (string) --The name of the Amazon S3 bucket where the access logs are stored.
    
    EmitInterval (integer) --The interval for publishing the access logs. You can specify an interval of either 5 minutes or 60 minutes.
    Default: 60 minutes
    
    S3BucketPrefix (string) --The logical hierarchy you created for your Amazon S3 bucket, for example my-bucket-prefix/prod . If the prefix is not provided, the log is placed at the root level of the bucket.
    
    
    
    ConnectionDraining (dict) --If enabled, the load balancer allows existing requests to complete before the load balancer shifts traffic away from a deregistered or unhealthy instance.
    For more information, see Configure Connection Draining in the Classic Load Balancer Guide .
    
    Enabled (boolean) -- [REQUIRED]Specifies whether connection draining is enabled for the load balancer.
    
    Timeout (integer) --The maximum time, in seconds, to keep the existing connections open before deregistering the instances.
    
    
    
    ConnectionSettings (dict) --If enabled, the load balancer allows the connections to remain idle (no data is sent over the connection) for the specified duration.
    By default, Elastic Load Balancing maintains a 60-second idle connection timeout for both front-end and back-end connections of your load balancer. For more information, see Configure Idle Connection Timeout in the Classic Load Balancer Guide .
    
    IdleTimeout (integer) -- [REQUIRED]The time, in seconds, that the connection is allowed to be idle (no data has been sent over the connection) before it is closed by the load balancer.
    
    
    
    AdditionalAttributes (list) --This parameter is reserved.
    
    (dict) --This data type is reserved.
    
    Key (string) --This parameter is reserved.
    
    Value (string) --This parameter is reserved.
    
    
    
    
    
    
    
    
    """
    pass

def register_instances_with_load_balancer(LoadBalancerName=None, Instances=None):
    """
    Adds the specified instances to the specified load balancer.
    The instance must be a running instance in the same network as the load balancer (EC2-Classic or the same VPC). If you have EC2-Classic instances and a load balancer in a VPC with ClassicLink enabled, you can link the EC2-Classic instances to that VPC and then register the linked EC2-Classic instances with the load balancer in the VPC.
    Note that RegisterInstanceWithLoadBalancer completes when the request has been registered. Instance registration takes a little time to complete. To check the state of the registered instances, use  DescribeLoadBalancers or  DescribeInstanceHealth .
    After the instance is registered, it starts receiving traffic and requests from the load balancer. Any instance that is not in one of the Availability Zones registered for the load balancer is moved to the OutOfService state. If an Availability Zone is added to the load balancer later, any instances registered with the load balancer move to the InService state.
    To deregister instances from a load balancer, use  DeregisterInstancesFromLoadBalancer .
    For more information, see Register or De-Register EC2 Instances in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example registers the specified instance with the specified load balancer.
    Expected Output:
    
    :example: response = client.register_instances_with_load_balancer(
        LoadBalancerName='string',
        Instances=[
            {
                'InstanceId': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type Instances: list
    :param Instances: [REQUIRED]
            The IDs of the instances.
            (dict) --The ID of an EC2 instance.
            InstanceId (string) --The instance ID.
            
            

    :rtype: dict
    :return: {
        'Instances': [
            {
                'InstanceId': 'string'
            },
        ]
    }
    
    
    """
    pass

def remove_tags(LoadBalancerNames=None, Tags=None):
    """
    Removes one or more tags from the specified load balancer.
    See also: AWS API Documentation
    
    Examples
    This example removes the specified tag from the specified load balancer.
    Expected Output:
    
    :example: response = client.remove_tags(
        LoadBalancerNames=[
            'string',
        ],
        Tags=[
            {
                'Key': 'string'
            },
        ]
    )
    
    
    :type LoadBalancerNames: list
    :param LoadBalancerNames: [REQUIRED]
            The name of the load balancer. You can specify a maximum of one load balancer name.
            (string) --
            

    :type Tags: list
    :param Tags: [REQUIRED]
            The list of tag keys to remove.
            (dict) --The key of a tag.
            Key (string) --The name of the key.
            
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def set_load_balancer_listener_ssl_certificate(LoadBalancerName=None, LoadBalancerPort=None, SSLCertificateId=None):
    """
    Sets the certificate that terminates the specified listener's SSL connections. The specified certificate replaces any prior certificate that was used on the same load balancer and port.
    For more information about updating your SSL certificate, see Replace the SSL Certificate for Your Load Balancer in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example replaces the existing SSL certificate for the specified HTTPS listener.
    Expected Output:
    
    :example: response = client.set_load_balancer_listener_ssl_certificate(
        LoadBalancerName='string',
        LoadBalancerPort=123,
        SSLCertificateId='string'
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type LoadBalancerPort: integer
    :param LoadBalancerPort: [REQUIRED]
            The port that uses the specified SSL certificate.
            

    :type SSLCertificateId: string
    :param SSLCertificateId: [REQUIRED]
            The Amazon Resource Name (ARN) of the SSL certificate.
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def set_load_balancer_policies_for_backend_server(LoadBalancerName=None, InstancePort=None, PolicyNames=None):
    """
    Replaces the set of policies associated with the specified port on which the EC2 instance is listening with a new set of policies. At this time, only the back-end server authentication policy type can be applied to the instance ports; this policy type is composed of multiple public key policies.
    Each time you use SetLoadBalancerPoliciesForBackendServer to enable the policies, use the PolicyNames parameter to list the policies that you want to enable.
    You can use  DescribeLoadBalancers or  DescribeLoadBalancerPolicies to verify that the policy is associated with the EC2 instance.
    For more information about enabling back-end instance authentication, see Configure Back-end Instance Authentication in the Classic Load Balancer Guide . For more information about Proxy Protocol, see Configure Proxy Protocol Support in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example replaces the policies that are currently associated with the specified port.
    Expected Output:
    
    :example: response = client.set_load_balancer_policies_for_backend_server(
        LoadBalancerName='string',
        InstancePort=123,
        PolicyNames=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type InstancePort: integer
    :param InstancePort: [REQUIRED]
            The port number associated with the EC2 instance.
            

    :type PolicyNames: list
    :param PolicyNames: [REQUIRED]
            The names of the policies. If the list is empty, then all current polices are removed from the EC2 instance.
            (string) --
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

def set_load_balancer_policies_of_listener(LoadBalancerName=None, LoadBalancerPort=None, PolicyNames=None):
    """
    Replaces the current set of policies for the specified load balancer port with the specified set of policies.
    To enable back-end server authentication, use  SetLoadBalancerPoliciesForBackendServer .
    For more information about setting policies, see Update the SSL Negotiation Configuration , Duration-Based Session Stickiness , and Application-Controlled Session Stickiness in the Classic Load Balancer Guide .
    See also: AWS API Documentation
    
    Examples
    This example replaces the policies that are currently associated with the specified listener.
    Expected Output:
    
    :example: response = client.set_load_balancer_policies_of_listener(
        LoadBalancerName='string',
        LoadBalancerPort=123,
        PolicyNames=[
            'string',
        ]
    )
    
    
    :type LoadBalancerName: string
    :param LoadBalancerName: [REQUIRED]
            The name of the load balancer.
            

    :type LoadBalancerPort: integer
    :param LoadBalancerPort: [REQUIRED]
            The external port of the load balancer.
            

    :type PolicyNames: list
    :param PolicyNames: [REQUIRED]
            The names of the policies. This list must include all policies to be enabled. If you omit a policy that is currently enabled, it is disabled. If the list is empty, all current policies are disabled.
            (string) --
            

    :rtype: dict
    :return: {}
    
    
    """
    pass

